import React from "react";
import { Button, Badge } from "antd";
import { useNavigate } from "react-router-dom";
import List from "@/components/Page/List";
import {
  getTaIssue,
  getTaOrgIssue,
  exportTaIssue,
  exportTaOrgIssue,
} from "@/service/taissue";
import { getTdLocType } from "@/service/tdloctype";
import { getSysOrg } from "@/service/sysorg";
import { queryDict } from "@/utils/request";
import { processEnum, processStatus } from "@/utils/biz";
import useBool from "@/utils/hooks/useBool";
import useOrgResponsible from "@/utils/hooks/useOrgResponsible";
import dayjs from "dayjs";

const queryOrg = queryDict(getSysOrg, { labelKey: "name", valueKey: "orgId" });
const queryLocType = queryDict(getTdLocType, {
  labelKey: "name",
  valueKey: "typeId",
});

const yestoday = dayjs().subtract(1, "day").format("YYYY-MM-DD");
export default (props) => {
  const [loading, startLoading, stopLoading] = useBool();
  const navigate = useNavigate();
  const paramsRef = React.useRef();

  const [isResponsible, org] = useOrgResponsible();
  const [request, params, exportFn] = React.useMemo(() => {
    return [
      isResponsible ? getTaOrgIssue : getTaIssue,
      isResponsible ? { orgId: org?.orgId } : { all: true },
      isResponsible ? exportTaOrgIssue : exportTaIssue,
    ];
  }, [isResponsible, org]);

  const columns = [
    {
      title: "问题单号",
      dataIndex: "issueId",
    },
    {
      title: "创建时间",
      dataIndex: "createdAt",
      valueType: "dateRange",
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            createDateStart: value[0],
            createDateEnd: value[1],
          };
        },
      },
    },
    {
      title: "办结时间",
      dataIndex: "createdAts",
      valueType: "dateRange",
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            endDateStart: value[0],
            endDateEnd: value[1],
          };
        },
      },
    },
    {
      title: "上报日期",
      dataIndex: "createDate",
      valueType: "date",
      hideInSearch: true,
    },
    {
      title: "点位",
      dataIndex: "locId",
      valueType: "select",
      request: queryLocType,
    },
    {
      title: "位置",
      dataIndex: "addr",
      hideInSearch: true,
    },
    {
      title: "问题详情",
      dataIndex: "content",
      hideInSearch: true,
      ellipsis: true,
    },
    {
      title: "责任单位",
      dataIndex: "orgId",
      valueType: "select",
      request: queryOrg,
      hideInSearch: isResponsible,
    },
    {
      title: "流程状态",
      dataIndex: "bizStatus",
      valueType: "select",
      valueEnum: processEnum,
      render: (_, row) => {
        if (row.processNode != "03" && yestoday > row.expireDate) {
          return <Badge status="error" text="已逾期" />;
        } else if(row.processNode=="03"&& yestoday > row.expireDate){
          return <Badge status="warning" text="延期办结" />;
        } else {
          const st = processStatus.filter((x) => x.value == row.processNode)[0];
          return <Badge status={st?.badge} text={st?.label} />;
        }
      },
    },
    {
      title: "截止日期",
      dataIndex: "expireDate",
      hideInSearch: true,
    },
    {
      title: "上报人",
      dataIndex: "userName",
      hideInSearch: true,
    },
  ];

  const onExport = () => {
    startLoading();
    exportFn(paramsRef.current)
      .then(() => {
        stopLoading();
      })
      .catch(() => {
        stopLoading();
      });
  };

  const beforeSearchSubmit = (params) => {
    paramsRef.current = {
      ...(params || {}),
      all: true,
    };
    return params;
  };

  return (
    <List
      rowKey="issueId"
      request={request}
      columns={columns}
      params={params}
      beforeSearchSubmit={beforeSearchSubmit}
      optionRender={(_, row) => [
        <Button
          key="detail"
          type="link"
          onClick={() => navigate(`/issue/detail?id=${row.issueId}`)}
        >
          详情
        </Button>,
      ]}
      toolBarRender={() => [
        <Button key="1" type="primary" loading={loading} onClick={onExport}>
          导出
        </Button>,
      ]}
    />
  );
};
